lkml.org 
[lkml]   [2022]   [May]   [26]   [last100]   RSS Feed
Views: [wrap][no wrap]   [headers]  [forward] 
 
Messages in this thread
Patch in this message
/
From
Subject[PATCH 27/31] OPP: Remove dev_pm_opp_set_clkname() and friends
Date
Now that everyone has migrated to dev_pm_opp_set_config(), remove the
public interface for dev_pm_opp_set_clkname() and friends.

Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
---
drivers/opp/core.c | 93 ++++++++++--------------------------------
include/linux/pm_opp.h | 15 -------
2 files changed, 21 insertions(+), 87 deletions(-)

diff --git a/include/linux/pm_opp.h b/include/linux/pm_opp.h
index b80982e5a067..7afa8160590d 100644
--- a/include/linux/pm_opp.h
+++ b/include/linux/pm_opp.h
@@ -186,9 +186,6 @@ void dev_pm_opp_clear_config(struct opp_table *opp_table);

struct opp_table *dev_pm_opp_set_prop_name(struct device *dev, const char *name);
void dev_pm_opp_put_prop_name(struct opp_table *opp_table);
-struct opp_table *dev_pm_opp_set_clkname(struct device *dev, const char *name);
-void dev_pm_opp_put_clkname(struct opp_table *opp_table);
-int devm_pm_opp_set_clkname(struct device *dev, const char *name);
struct opp_table *dev_pm_opp_register_set_opp_helper(struct device *dev, int (*set_opp)(struct dev_pm_set_opp_data *data));
void dev_pm_opp_unregister_set_opp_helper(struct opp_table *opp_table);
int devm_pm_opp_register_set_opp_helper(struct device *dev, int (*set_opp)(struct dev_pm_set_opp_data *data));
@@ -387,18 +384,6 @@ static inline struct opp_table *dev_pm_opp_set_prop_name(struct device *dev, con

static inline void dev_pm_opp_put_prop_name(struct opp_table *opp_table) {}

-static inline struct opp_table *dev_pm_opp_set_clkname(struct device *dev, const char *name)
-{
- return ERR_PTR(-EOPNOTSUPP);
-}
-
-static inline void dev_pm_opp_put_clkname(struct opp_table *opp_table) {}
-
-static inline int devm_pm_opp_set_clkname(struct device *dev, const char *name)
-{
- return -EOPNOTSUPP;
-}
-
static inline struct opp_table *dev_pm_opp_attach_genpd(struct device *dev, const char * const *names, struct device ***virt_devs)
{
return ERR_PTR(-EOPNOTSUPP);
diff --git a/drivers/opp/core.c b/drivers/opp/core.c
index 07cb8ff33a6d..c2590c0c05a0 100644
--- a/drivers/opp/core.c
+++ b/drivers/opp/core.c
@@ -2152,7 +2152,7 @@ static void _opp_put_regulators(struct opp_table *opp_table)
}

/**
* dev_pm_opp_set_clkname() - Set clk name for the device
* @dev: Device for which clk name is being set.
* @name: Clk name.
*
@@ -2163,93 +2163,41 @@ static void _opp_put_regulators(struct opp_table *opp_table)
*
* This must be called before any OPPs are initialized for the device.
*/
-struct opp_table *dev_pm_opp_set_clkname(struct device *dev, const char *name)
+static int _opp_set_clkname(struct opp_table *opp_table, struct device *dev,
+ const char *name)
{
- struct opp_table *opp_table;
- int ret;
-
- opp_table = _add_opp_table(dev, false);
- if (IS_ERR(opp_table))
- return opp_table;
-
- /* This should be called before OPPs are initialized */
- if (WARN_ON(!list_empty(&opp_table->opp_list))) {
- ret = -EBUSY;
- goto err;
- }
-
/* Another CPU that shares the OPP table has set the clkname ? */
if (opp_table->clk_configured)
- return opp_table;
+ return 0;

/* clk shouldn't be initialized at this point */
- if (WARN_ON(opp_table->clk)) {
- ret = -EBUSY;
- goto err;
- }
+ if (WARN_ON(opp_table->clk))
+ return -EBUSY;

/* Find clk for the device */
opp_table->clk = clk_get(dev, name);
if (IS_ERR(opp_table->clk)) {
- ret = dev_err_probe(dev, PTR_ERR(opp_table->clk),
+ return dev_err_probe(dev, PTR_ERR(opp_table->clk),
"%s: Couldn't find clock\n", __func__);
- goto err;
}

opp_table->clk_configured = true;

- return opp_table;
-
-err:
- dev_pm_opp_put_opp_table(opp_table);
-
- return ERR_PTR(ret);
-}
-EXPORT_SYMBOL_GPL(dev_pm_opp_set_clkname);
-
-/**
- * dev_pm_opp_put_clkname() - Releases resources blocked for clk.
- * @opp_table: OPP table returned from dev_pm_opp_set_clkname().
- */
-void dev_pm_opp_put_clkname(struct opp_table *opp_table)
-{
- if (unlikely(!opp_table))
- return;
-
- clk_put(opp_table->clk);
- opp_table->clk = ERR_PTR(-EINVAL);
- opp_table->clk_configured = false;
-
- dev_pm_opp_put_opp_table(opp_table);
-}
-EXPORT_SYMBOL_GPL(dev_pm_opp_put_clkname);
-
-static void devm_pm_opp_clkname_release(void *data)
-{
- dev_pm_opp_put_clkname(data);
+ return 0;
}

/**
- * devm_pm_opp_set_clkname() - Set clk name for the device
- * @dev: Device for which clk name is being set.
- * @name: Clk name.
- *
- * This is a resource-managed variant of dev_pm_opp_set_clkname().
- *
- * Return: 0 on success and errorno otherwise.
+ * _opp_put_clkname() - Releases resources blocked for clk.
+ * @opp_table: OPP table returned from _opp_set_clkname().
*/
-int devm_pm_opp_set_clkname(struct device *dev, const char *name)
+static void _opp_put_clkname(struct opp_table *opp_table)
{
- struct opp_table *opp_table;
-
- opp_table = dev_pm_opp_set_clkname(dev, name);
- if (IS_ERR(opp_table))
- return PTR_ERR(opp_table);
-
- return devm_add_action_or_reset(dev, devm_pm_opp_clkname_release,
- opp_table);
+ if (opp_table->clk_configured) {
+ clk_put(opp_table->clk);
+ opp_table->clk = ERR_PTR(-EINVAL);
+ opp_table->clk_configured = false;
+ }
}
-EXPORT_SYMBOL_GPL(devm_pm_opp_set_clkname);

/**
* dev_pm_opp_register_set_opp_helper() - Register custom set OPP helper
@@ -2549,9 +2497,11 @@ struct opp_table *dev_pm_opp_set_config(struct device *dev,

// Configure clock
if (config->clk_name) {
- ret = dev_pm_opp_set_clkname(dev, config->clk_name);
- if (IS_ERR(ret))
+ err = _opp_set_clkname(opp_table, dev, config->clk_name);
+ if (err) {
+ ret = ERR_PTR(err);
goto err;
+ }
}

// Configure property names
@@ -2633,8 +2583,7 @@ void dev_pm_opp_clear_config(struct opp_table *opp_table)
if (opp_table->prop_name)
dev_pm_opp_put_prop_name(opp_table);

- if (opp_table->clk_configured)
- dev_pm_opp_put_clkname(opp_table);
+ _opp_put_clkname(opp_table);

dev_pm_opp_put_opp_table(opp_table);
}
@@ -2152,7 +2152,7 @@ static void _opp_put_regulators(struct opp_table *opp_table)

/**
- * dev_pm_opp_set_clkname() - Set clk name for the device
+ * _opp_set_clkname() - Set clk name for the device
* @dev: Device for which clk name is being set.
* @name: Clk name.
--
2.31.1.272.g89b43f80a514
\
 
 \ /
  Last update: 2022-05-26 13:47    [W:0.127 / U:0.320 seconds]
©2003-2020 Jasper Spaans|hosted at Digital Ocean and TransIP|Read the blog|Advertise on this site